@@ -2,8 +2,8 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-03-06 23:17:54
-@LastEditTime: ,: 2020-10-21 16:13:14
-@LastEditors: ,: ChenXiaolei
+@LastEditTime: 2020-11-23 17:34:10
+@LastEditors: ChenXiaolei
 @Description: 数据库基础操作类
 """
 
@@ -355,10 +355,9 @@ class BaseModel:
         update_field_str = ""
 
         param = []
-        mid = ""
+        mid = getattr(model,self.primary_key_field)
         for field_str in field_list:
             if self.primary_key_field and str(field_str).lower() == self.primary_key_field.lower():
-                mid = getattr(model, field_str)
                 continue
             update_field_str += str(field_str + "=%s,")
             if str(field_str).lower() == "edit_on":
@@ -404,10 +403,9 @@ class BaseModel:
             update_field_str = ""
 
             param = []
-            mid = ""
+            mid = getattr(model,self.primary_key_field)
             for field_str in field_list:
                 if self.primary_key_field and str(field_str).lower() == self.primary_key_field.lower():
-                    mid = getattr(model, field_str)
                     continue
                 update_field_str += str(field_str + "=%s,")
                 if str(field_str).lower() == "edit_on":
