@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-04-16 14:38:22
-@LastEditTime: 2020-05-06 20:30:57
+@LastEditTime: 2020-07-10 17:36:18
 @LastEditors: ChenXiaolei
 @Description: 
 """
@@ -97,6 +97,23 @@ class CryptoHelper:
             sha1_sign.update(source)
         return sha1_sign.hexdigest()
 
+    @classmethod
+    def sha256_encrypt(self, source, encoding="utf-8"):
+        """
+        @description: sha256加密
+        @param source: 需加密的字符串
+        @return: sha256加密后的字符串
+        @last_editors: ChenXiaolei
+        """
+        import hashlib
+        sha256 = hashlib.sha256()
+        if isinstance(source, str):
+            sha256.update(source.encode(encoding))
+        elif isinstance(source, bytes):
+            sha256.update(source)
+        result = sha256.hexdigest()
+        return result
+
     @classmethod
     def base64_encode(self, source, encoding="utf-8"):
         """
