@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-04-26 14:11:31
-@LastEditTime: 2020-04-26 14:15:16
+@LastEditTime: 2020-05-28 11:23:16
 @LastEditors: ChenXiaolei
 @Description: 
 """
@@ -16,10 +16,13 @@ class HostHelper:
         查询本机ip地址
         :return: ip
         """
+        ip = ""
         try:
             s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-            s.connect(('8.8.8.8', 80))
+            s.connect(('114.114.114.114', 80))
             ip = s.getsockname()[0]
+        except:
+            pass
         finally:
             s.close()
 
