@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-04-16 21:32:43
-@LastEditTime: 2020-05-23 16:11:23
+@LastEditTime: 2020-07-08 10:28:09
 @LastEditors: ChenXiaolei
 @Description: 
 """
@@ -141,7 +141,7 @@ class LoggerMysqlHandler(logging.Handler):
 
             if not exist_result:
                 self.db.fetch_and_commit(
-                    f"CREATE TABLE `{table_name}` ( `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键id', `project_name` varchar(50) DEFAULT NULL COMMENT '项目名称', `level` varchar(20) DEFAULT NULL COMMENT '日志等级', `host_ip` varchar(50) DEFAULT NULL COMMENT '服务器ip', `record_time` int(11) NOT NULL COMMENT '记录时间', `log_msg` longtext NOT NULL COMMENT '日志内容', PRIMARY KEY (`id`) ) ENGINE=InnoDB DEFAULT CHARSET=utf8;")
+                    f"CREATE TABLE `{table_name}` ( `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键id', `project_name` varchar(50) DEFAULT NULL COMMENT '项目名称', `level` varchar(20) DEFAULT NULL COMMENT '日志等级', `host_ip` varchar(50) DEFAULT NULL COMMENT '服务器ip', `record_time` datetime NOT NULL COMMENT '记录时间', `record_timestamp` int(11) NOT NULL COMMENT '记录时间',`log_msg` longtext NOT NULL COMMENT '日志内容', PRIMARY KEY (`id`) ) ENGINE=InnoDB DEFAULT CHARSET=utf8;")
             logging.Handler.__init__(self)
         except Exception as ex:
             print(ex)
@@ -150,7 +150,7 @@ class LoggerMysqlHandler(logging.Handler):
     def emit(self, record):
         try:
             self.db.fetch_and_commit(
-                f"INSERT INTO {self.table_name}(project_name,level,host_ip,record_time,log_msg) VALUE('{self.project_name}','{record.levelname}','{self.host_ip}',{int(record.created)},'{record.message}');")
+                f"INSERT INTO {self.table_name}(project_name,level,host_ip,record_time,record_timestamp,log_msg) VALUE('{self.project_name}','{record.levelname}','{self.host_ip}','{time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(int(record.created)))}',{int(record.created)},'{pymysql.escape_string(record.message)}');")
         except Exception as ex:
             print(ex)
             pass
