@@ -105,8 +105,8 @@ class MySQLHelper(object):
     def _execute(self, sql, params=None):
         self.connection()
 
-        if params and type(params) != list:
-            params = [params]
+        if params!=None and type(params)==int:
+            params=[params]
 
         try:
 
