@@ -444,6 +444,7 @@ class TimeHelper:
                 minuend_time, subtracter_time, format='%Y-%m-%d %H:%M:%S') /
             60 / 60)
 
+    @classmethod
     def get_first_day_of_the_week(self):
         """
         @description: 获取本周一的日期
@@ -455,6 +456,7 @@ class TimeHelper:
         return (now_datetime -
                 datetime.timedelta(days=now_datetime.weekday())).date()
 
+    @classmethod
     def get_last_day_of_the_week(self):
         """
         @description: 获取本周日的日期
@@ -466,6 +468,7 @@ class TimeHelper:
         return (now_datetime +
                 datetime.timedelta(days=6 - now_datetime.weekday())).date()
 
+    @classmethod
     def is_this_week(self, date, format='%Y-%m-%d %H:%M:%S'):
         """
         @description: 指定时间是否在本周内
@@ -479,10 +482,11 @@ class TimeHelper:
         elif type(date) == str:
             compare_datetime = self.format_time_to_datetime(date, format)
         if compare_datetime.date() >= self.get_first_day_of_the_week(
-        ) and compare_datetime.date() < self.get_last_day_of_the_week():
+        ) and compare_datetime.date() <= self.get_last_day_of_the_week():
             return True
         return False
 
+    @classmethod
     def get_first_day_of_the_month(self):
         """
         @description: 获取本月第一天的日期
@@ -493,6 +497,7 @@ class TimeHelper:
         now_datetime = self.get_now_datetime()
         return datetime.datetime(now_datetime.year, now_datetime.month, 1)
 
+    @classmethod
     def get_last_day_of_the_month(self):
         """
         @description: 获取本月最后一天的日期
@@ -504,6 +509,7 @@ class TimeHelper:
         return datetime.datetime(now_datetime.year, now_datetime.month + 1,
                                  1) - datetime.timedelta(days=1)
 
+    @classmethod
     def is_this_month(self, date, format='%Y-%m-%d %H:%M:%S'):
         """
         @description: 指定时间是否在本周内
@@ -517,10 +523,11 @@ class TimeHelper:
         elif type(date) == str:
             compare_datetime = self.format_time_to_datetime(date, format)
         if compare_datetime >= self.get_first_day_of_the_month(
-        ) and compare_datetime < self.get_last_day_of_the_month():
+        ) and compare_datetime <= self.get_last_day_of_the_month():
             return True
         return False
 
+    @classmethod
     def get_first_day_of_the_year(self):
         """
         @description: 获取本年第一天的日期
@@ -531,6 +538,7 @@ class TimeHelper:
         now_datetime = self.get_now_datetime()
         return datetime.datetime(now_datetime.year, 1, 1)
 
+    @classmethod
     def get_last_day_of_the_year(self):
         """
         @description: 获取本年最后一天的日期
@@ -539,8 +547,10 @@ class TimeHelper:
         @last_editors: ChenXiaolei
         """
         now_datetime = self.get_now_datetime()
-        return datetime.datetime(now_datetime.year + 1, 1, 1) - datetime.timedelta(days=1)
+        return datetime.datetime(now_datetime.year + 1, 1,
+                                 1) - datetime.timedelta(days=1)
 
+    @classmethod
     def is_this_year(self, date, format='%Y-%m-%d %H:%M:%S'):
         """
         @description: 指定时间是否在本年内
@@ -554,6 +564,6 @@ class TimeHelper:
         elif type(date) == str:
             compare_datetime = self.format_time_to_datetime(date, format)
         if compare_datetime >= self.get_first_day_of_the_year(
-        ) and compare_datetime < self.get_last_day_of_the_year():
+        ) and compare_datetime <= self.get_last_day_of_the_year():
             return True
         return False
\ No newline at end of file
