@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-03-06 23:17:54
-@LastEditTime: 2020-05-13 20:02:41
+@LastEditTime: 2020-05-27 16:30:11
 @LastEditors: ChenXiaolei
 @Description: Handler基础类
 """
@@ -29,7 +29,7 @@ class BaseApiHandler(BaseHandler):
         @description: 重写全局异常事件捕捉
         @last_editors: ChenXiaolei
         """
-        self.logger_error.exception('error_info:')
+        self.logger_error.error(traceback.format_exc())
         return self.reponse_json_error()
 
     def prepare_ext(self):
