@@ -2,7 +2,7 @@
 """
 @Author: ChenXiaolei
 @Date: 2020-03-06 23:17:54
-@LastEditTime: 2020-06-01 19:04:50
+@LastEditTime: 2020-12-03 09:54:36
 @LastEditors: ChenXiaolei
 @Description: Handler基础类
 """
@@ -89,13 +89,13 @@ class BaseHandler(tornado.web.RequestHandler):
                 http_status_code=self.get_status(),
             )
 
-            http_request_json = json.dumps(http_request, cls=JsonEncoder)
+            http_request_msg =f"http_reponse:{json.dumps(http_request, cls=JsonEncoder)}"
 
             http_log = config.get_value("http_log")
             if http_log and http_log == True:
-                self.logger_info.info(http_request_json)
+                self.logger_info.info(http_request_msg)
             else:
-                print('\033[33m' + http_request_json + '\033[0m')
+                print('\033[33m' + http_request_msg + '\033[0m')
 
             self.prepare_ext()
         except Exception as ex:
@@ -271,6 +271,12 @@ class BaseHandler(tornado.web.RequestHandler):
         @return: 将字符串返回给客户端
         @last_editors: ChenXiaolei
         """
+        http_log = config.get_value("http_log")
+        content_log_info = f"http_reponse:{content}"
+        if http_log and http_log == True:
+            self.logger_info.info(content_log_info)
+        else:
+            print('\033[32m' + content_log_info + '\033[0m')
         self.write(content)
 
     def reponse_json_success(self, data=None, desc='success'):
